/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: aqofxconnect_l.h 418 2005-08-08 02:24:41Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQOFXCONNECT_AQOFXCONNECT_L_H
#define AQOFXCONNECT_AQOFXCONNECT_L_H

#include <aqofxconnect/aqofxconnect.h>

#ifdef HAVE_I18N
# ifdef HAVE_LOCALE_H
#  include <locale.h>
# endif
# ifdef HAVE_LIBINTL_H
#  include <libintl.h>
# endif

# define I18N(msg) dgettext(PACKAGE, msg)
#else
# define I18N(msg) msg
#endif

#define I18N_NOOP(msg) msg



#endif /* AQOFXCONNECT_AQOFXCONNECT_L_H */

